@@ -107,6 +107,10 @@ def make_invoice_for_entry(entry, **kwargs):
     inv.balance = price
     inv.due_date = now
     inv.ship_date = now
+    
+    if entry.creator and not entry.creator.is_anonymous():
+        inv.set_owner(entry.creator)
+
     inv.save()
     
     return inv
